@@ -8,6 +8,6 @@ def restart():
 async def join(client):
     try:
         await client.join_chat("RendyProjects")
-        await client.join_chat("pantekyks")
+        await client.join_chat("KillerXSupport")
     except BaseException:
         pass
